# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.resource_list_policy_assignment import ResourceListPolicyAssignment

class TestResourceListPolicyAssignment(unittest.TestCase):
    """ResourceListPolicyAssignment unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResourceListPolicyAssignment:
        """Test ResourceListPolicyAssignment
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResourceListPolicyAssignment`
        """
        model = ResourceListPolicyAssignment()
        if include_optional:
            return ResourceListPolicyAssignment(
                records = [
                    arthur_client.api_bindings.models.policy_assignment.PolicyAssignment(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        policy = arthur_client.api_bindings.models.policy_summary.PolicySummary(
                            id = '', 
                            name = '', 
                            description = '', ), 
                        model = arthur_client.api_bindings.models.model_summary.ModelSummary(
                            id = '', 
                            name = '', 
                            project_id = '', ), 
                        applied_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        applied_by_user_id = '', 
                        enforcement_starts_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        compliance_status = arthur_client.api_bindings.models.compliance_status_detail.ComplianceStatusDetail(
                            status = 'PENDING', 
                            alert_rules = arthur_client.api_bindings.models.compliance_alert_rule_results.ComplianceAlertRuleResults(
                                compliant = [
                                    arthur_client.api_bindings.models.compliant_alert_rule_status.CompliantAlertRuleStatus(
                                        id = '', 
                                        name = '', )
                                    ], 
                                non_compliant = [
                                    arthur_client.api_bindings.models.non_compliant_alert_rule_status.NonCompliantAlertRuleStatus(
                                        id = '', 
                                        name = '', 
                                        alert = arthur_client.api_bindings.models.compliance_alert_summary.ComplianceAlertSummary(
                                            description = '', 
                                            id = '', ), )
                                    ], ), 
                            attestation_rules = arthur_client.api_bindings.models.compliance_attestation_rule_results.ComplianceAttestationRuleResults(), ), 
                        compliance_job = arthur_client.api_bindings.models.job.Job(
                            id = '', 
                            kind = 'metrics_calculation', 
                            job_spec = null, 
                            state = 'queued', 
                            project_id = '', 
                            data_plane_id = '', 
                            queued_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            ready_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            duration_sec = 56, 
                            error_count = 56, 
                            trigger_type = 'user', 
                            triggered_by_user = arthur_client.api_bindings.models.user.User(
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                organization_id = '', 
                                id = '', 
                                first_name = '', 
                                last_name = '', 
                                email = '', 
                                picture = '', 
                                user_type = 'user', 
                                data_plane_id = '', 
                                client_id = '', 
                                organization_name = '', ), 
                            schedule_id = '', 
                            attempts = 56, 
                            max_attempts = 56, 
                            nonce = '', 
                            memory_requirements_mb = 56, 
                            job_priority = 100, ), 
                        last_violation_notified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                pagination = arthur_client.api_bindings.models.pagination.Pagination(
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    total_records = 56, )
            )
        else:
            return ResourceListPolicyAssignment(
                records = [
                    arthur_client.api_bindings.models.policy_assignment.PolicyAssignment(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        policy = arthur_client.api_bindings.models.policy_summary.PolicySummary(
                            id = '', 
                            name = '', 
                            description = '', ), 
                        model = arthur_client.api_bindings.models.model_summary.ModelSummary(
                            id = '', 
                            name = '', 
                            project_id = '', ), 
                        applied_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        applied_by_user_id = '', 
                        enforcement_starts_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        compliance_status = arthur_client.api_bindings.models.compliance_status_detail.ComplianceStatusDetail(
                            status = 'PENDING', 
                            alert_rules = arthur_client.api_bindings.models.compliance_alert_rule_results.ComplianceAlertRuleResults(
                                compliant = [
                                    arthur_client.api_bindings.models.compliant_alert_rule_status.CompliantAlertRuleStatus(
                                        id = '', 
                                        name = '', )
                                    ], 
                                non_compliant = [
                                    arthur_client.api_bindings.models.non_compliant_alert_rule_status.NonCompliantAlertRuleStatus(
                                        id = '', 
                                        name = '', 
                                        alert = arthur_client.api_bindings.models.compliance_alert_summary.ComplianceAlertSummary(
                                            description = '', 
                                            id = '', ), )
                                    ], ), 
                            attestation_rules = arthur_client.api_bindings.models.compliance_attestation_rule_results.ComplianceAttestationRuleResults(), ), 
                        compliance_job = arthur_client.api_bindings.models.job.Job(
                            id = '', 
                            kind = 'metrics_calculation', 
                            job_spec = null, 
                            state = 'queued', 
                            project_id = '', 
                            data_plane_id = '', 
                            queued_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            ready_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            duration_sec = 56, 
                            error_count = 56, 
                            trigger_type = 'user', 
                            triggered_by_user = arthur_client.api_bindings.models.user.User(
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                organization_id = '', 
                                id = '', 
                                first_name = '', 
                                last_name = '', 
                                email = '', 
                                picture = '', 
                                user_type = 'user', 
                                data_plane_id = '', 
                                client_id = '', 
                                organization_name = '', ), 
                            schedule_id = '', 
                            attempts = 56, 
                            max_attempts = 56, 
                            nonce = '', 
                            memory_requirements_mb = 56, 
                            job_priority = 100, ), 
                        last_violation_notified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                pagination = arthur_client.api_bindings.models.pagination.Pagination(
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    total_records = 56, ),
        )
        """

    def testResourceListPolicyAssignment(self):
        """Test ResourceListPolicyAssignment"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ConnectorType(str, Enum):
    """
    ConnectorType
    """

    """
    allowed enum values
    """
    SHIELD = 'shield'
    S3 = 'S3'
    GCS = 'GCS'
    BIGQUERY = 'BigQuery'
    ENGINE_INTERNAL = 'engine_internal'
    ODBC = 'odbc'
    SNOWFLAKE = 'snowflake'
    DATABRICKS = 'databricks'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ConnectorType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from arthur_client.api_bindings.models.continuous_eval_response import ContinuousEvalResponse
from arthur_client.api_bindings.models.llm_eval import LLMEval
from arthur_client.api_bindings.models.task_response import TaskResponse
from arthur_client.api_bindings.models.trace_transform_response import TraceTransformResponse
from typing import Optional, Set
from typing_extensions import Self

class TaskReadResponse(BaseModel):
    """
    TaskReadResponse
    """ # noqa: E501
    task: Optional[TaskResponse] = None
    last_synced_at: Optional[datetime] = None
    scope_model_id: StrictStr = Field(description="The ID of the corresponding scope model for this task.")
    evals: Optional[List[LLMEval]] = None
    continuous_evals: Optional[List[ContinuousEvalResponse]] = None
    transforms: Optional[List[TraceTransformResponse]] = None
    __properties: ClassVar[List[str]] = ["task", "last_synced_at", "scope_model_id", "evals", "continuous_evals", "transforms"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TaskReadResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of task
        if self.task:
            _dict['task'] = self.task.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in evals (list)
        _items = []
        if self.evals:
            for _item_evals in self.evals:
                if _item_evals:
                    _items.append(_item_evals.to_dict())
            _dict['evals'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in continuous_evals (list)
        _items = []
        if self.continuous_evals:
            for _item_continuous_evals in self.continuous_evals:
                if _item_continuous_evals:
                    _items.append(_item_continuous_evals.to_dict())
            _dict['continuous_evals'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in transforms (list)
        _items = []
        if self.transforms:
            for _item_transforms in self.transforms:
                if _item_transforms:
                    _items.append(_item_transforms.to_dict())
            _dict['transforms'] = _items
        # set to None if task (nullable) is None
        # and model_fields_set contains the field
        if self.task is None and "task" in self.model_fields_set:
            _dict['task'] = None

        # set to None if last_synced_at (nullable) is None
        # and model_fields_set contains the field
        if self.last_synced_at is None and "last_synced_at" in self.model_fields_set:
            _dict['last_synced_at'] = None

        # set to None if evals (nullable) is None
        # and model_fields_set contains the field
        if self.evals is None and "evals" in self.model_fields_set:
            _dict['evals'] = None

        # set to None if continuous_evals (nullable) is None
        # and model_fields_set contains the field
        if self.continuous_evals is None and "continuous_evals" in self.model_fields_set:
            _dict['continuous_evals'] = None

        # set to None if transforms (nullable) is None
        # and model_fields_set contains the field
        if self.transforms is None and "transforms" in self.model_fields_set:
            _dict['transforms'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TaskReadResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "task": TaskResponse.from_dict(obj["task"]) if obj.get("task") is not None else None,
            "last_synced_at": obj.get("last_synced_at"),
            "scope_model_id": obj.get("scope_model_id"),
            "evals": [LLMEval.from_dict(_item) for _item in obj["evals"]] if obj.get("evals") is not None else None,
            "continuous_evals": [ContinuousEvalResponse.from_dict(_item) for _item in obj["continuous_evals"]] if obj.get("continuous_evals") is not None else None,
            "transforms": [TraceTransformResponse.from_dict(_item) for _item in obj["transforms"]] if obj.get("transforms") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from arthur_client.api_bindings.models.post_policy_alert_rule import PostPolicyAlertRule
from arthur_client.api_bindings.models.post_policy_attestation_rule import PostPolicyAttestationRule
from typing import Optional, Set
from typing_extensions import Self

class PostPolicy(BaseModel):
    """
    PostPolicy
    """ # noqa: E501
    name: StrictStr = Field(description="The name of the policy.")
    description: Optional[StrictStr] = None
    owner_group_id: StrictStr = Field(description="The ID of the group that owns this policy.")
    webhook_id: StrictStr = Field(description="The ID of the notification webhook.")
    enforcement_delay_days: StrictInt = Field(description="The number of days for the enforcement delay.")
    alert_rules: Optional[List[PostPolicyAlertRule]] = Field(default=None, description="Alert rules to create with the policy.")
    attestation_rules: Optional[List[PostPolicyAttestationRule]] = Field(default=None, description="Attestation rules to create with the policy.")
    __properties: ClassVar[List[str]] = ["name", "description", "owner_group_id", "webhook_id", "enforcement_delay_days", "alert_rules", "attestation_rules"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PostPolicy from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in alert_rules (list)
        _items = []
        if self.alert_rules:
            for _item_alert_rules in self.alert_rules:
                if _item_alert_rules:
                    _items.append(_item_alert_rules.to_dict())
            _dict['alert_rules'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in attestation_rules (list)
        _items = []
        if self.attestation_rules:
            for _item_attestation_rules in self.attestation_rules:
                if _item_attestation_rules:
                    _items.append(_item_attestation_rules.to_dict())
            _dict['attestation_rules'] = _items
        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PostPolicy from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "description": obj.get("description"),
            "owner_group_id": obj.get("owner_group_id"),
            "webhook_id": obj.get("webhook_id"),
            "enforcement_delay_days": obj.get("enforcement_delay_days"),
            "alert_rules": [PostPolicyAlertRule.from_dict(_item) for _item in obj["alert_rules"]] if obj.get("alert_rules") is not None else None,
            "attestation_rules": [PostPolicyAttestationRule.from_dict(_item) for _item in obj["attestation_rules"]] if obj.get("attestation_rules") is not None else None
        })
        return _obj


